==> ejc-ztpcdc-impl-3.0.0-20230720.060628-130-sources.jar: com/ejianc/business/dc/vo/DcSendFileVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 发文管理
 *
 * @author generator
 */
public class DcSendFileVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Integer billState; // 单据状态
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private String fileCode; // 外部编码
    private String fileInternalCode; // 内部编码
    private String fileName; // 文件名称
    private String fileVsn; // 版本
    private String fileSts; // 文件状态
    private String fileStsCn; // 文件状态中文
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date sendDate; // 发文日期
    private Long attribute; // 文件属性
    private Long filetype; // 文件类型
    private Long submitType; // 外报类型
    private String submitOrgCode; // 主送单位/部门编号
    private String submitOrgName; // 主送单位/部门
    private String submitOrgId;
    private String copyOrgId;
    private String copyOrgCode; // 抄送单位/部门编号
    private String copyOrgName; // 抄送单位/部门
    private String receiveFileCode; // 回复收文编号
    private Long centerId;//回复收文编号在分发中心表的主键id
    private Boolean needReplyFlag; // 是否需回复
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date needReplyDate; // 需回复日期
    private Boolean secretFlag; // 是否保密
    private Long bidsection; // 标段--字典pub_bidsection_code
    private Long mgrp; // 机组--字典pub_mgrp_code
    private Long specialty; // 专业--字典pub_specialty_code
    private Long sys; // 系统--字典pub_system_code
    private Long subItem; // 子项--字典pub_sub_item
    private Long materialType; // 材料类型--字典pub_material_type
    private String unitProjCode; // 单位工程代码
    private String unitProjName; // 单位工程名称
    private Long contractId; // 合同ID
    private String contractCode; // 合同编号
    private String contractName; // 合同名称
    private Boolean costFlag; // 是否涉费--字典flag_yn
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date replyDate; // 回复日期
    private String replyOpinion; // 回复意见
    private String replyAttachment; // 回复附件
    private String onlineAttachment; // 在线编辑正文附件
    private String fileAttachment; // 在线编辑自动生成的文件附件
    private String otherAttachment; // 其他附件
    private Long createDeptId; // 创建部门id
    private Long orgId; // 所属组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private Long mainActivities; // 主要活动--数据字典mainActivities
    private Long subentryActivities; // 分项活动
    private Long principalItem; // 主要种类
    private Long cmitTypeCode; // 通讯类型代码
    private Long receiverCmitCode; // 收文方通讯代码
    private String billCode; // 单据编码


    public String getFileCode() {
        return fileCode;
    }

    public void setFileCode(String fileCode) {
        this.fileCode = fileCode;
    }

    public String getFileInternalCode() {
        return fileInternalCode;
    }

    public void setFileInternalCode(String fileInternalCode) {
        this.fileInternalCode = fileInternalCode;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getFileVsn() {
        return fileVsn;
    }

    public void setFileVsn(String fileVsn) {
        this.fileVsn = fileVsn;
    }

    public String getFileSts() {
        return fileSts;
    }

    public void setFileSts(String fileSts) {
        this.fileSts = fileSts;
    }

    public Date getSendDate() {
        return sendDate;
    }

    public void setSendDate(Date sendDate) {
        this.sendDate = sendDate;
    }

    @ReferSerialTransfer(referCode = "contractCategory")
    public Long getAttribute() {
        return attribute;
    }

    @ReferDeserialTransfer
    public void setAttribute(Long attribute) {
        this.attribute = attribute;
    }

    @ReferSerialTransfer(referCode = "contractCategory")
    public Long getFiletype() {
        return filetype;
    }

    @ReferDeserialTransfer
    public void setFiletype(Long filetype) {
        this.filetype = filetype;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSubmitType() {
        return submitType;
    }

    @ReferDeserialTransfer
    public void setSubmitType(Long submitType) {
        this.submitType = submitType;
    }

    public String getSubmitOrgId() {
        return submitOrgId;
    }

    @ReferDeserialTransfer
    public void setSubmitOrgId(String submitOrgId) {
        this.submitOrgId = submitOrgId;
    }

    public String getCopyOrgId() {
        return copyOrgId;
    }

    @ReferDeserialTransfer
    public void setCopyOrgId(String copyOrgId) {
        this.copyOrgId = copyOrgId;
    }

    public String getSubmitOrgCode() {
        return submitOrgCode;
    }

    public void setSubmitOrgCode(String submitOrgCode) {
        this.submitOrgCode = submitOrgCode;
    }

    public String getSubmitOrgName() {
        return submitOrgName;
    }

    public void setSubmitOrgName(String submitOrgName) {
        this.submitOrgName = submitOrgName;
    }

    public String getCopyOrgCode() {
        return copyOrgCode;
    }

    public void setCopyOrgCode(String copyOrgCode) {
        this.copyOrgCode = copyOrgCode;
    }

    public String getCopyOrgName() {
        return copyOrgName;
    }

    public void setCopyOrgName(String copyOrgName) {
        this.copyOrgName = copyOrgName;
    }

    public String getReceiveFileCode() {
        return receiveFileCode;
    }

    public void setReceiveFileCode(String receiveFileCode) {
        this.receiveFileCode = receiveFileCode;
    }



    public Date getNeedReplyDate() {
        return needReplyDate;
    }

    public void setNeedReplyDate(Date needReplyDate) {
        this.needReplyDate = needReplyDate;
    }


    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getBidsection() {
        return bidsection;
    }

    @ReferDeserialTransfer
    public void setBidsection(Long bidsection) {
        this.bidsection = bidsection;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getMgrp() {
        return mgrp;
    }

    @ReferDeserialTransfer
    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getSpecialty() {
        return specialty;
    }

    @ReferDeserialTransfer
    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getSys() {
        return sys;
    }

    @ReferDeserialTransfer
    public void setSys(Long sys) {
        this.sys = sys;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSubItem() {
        return subItem;
    }

    @ReferDeserialTransfer
    public void setSubItem(Long subItem) {
        this.subItem = subItem;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMaterialType() {
        return materialType;
    }

    @ReferDeserialTransfer
    public void setMaterialType(Long materialType) {
        this.materialType = materialType;
    }

    public String getUnitProjCode() {
        return unitProjCode;
    }

    public void setUnitProjCode(String unitProjCode) {
        this.unitProjCode = unitProjCode;
    }

    public String getUnitProjName() {
        return unitProjName;
    }

    public void setUnitProjName(String unitProjName) {
        this.unitProjName = unitProjName;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Boolean getNeedReplyFlag() {
        return needReplyFlag;
    }

    public void setNeedReplyFlag(Boolean needReplyFlag) {
        this.needReplyFlag = needReplyFlag;
    }

    public Boolean getSecretFlag() {
        return secretFlag;
    }

    public void setSecretFlag(Boolean secretFlag) {
        this.secretFlag = secretFlag;
    }

    public Boolean getCostFlag() {
        return costFlag;
    }

    public void setCostFlag(Boolean costFlag) {
        this.costFlag = costFlag;
    }

    public Date getReplyDate() {
        return replyDate;
    }

    public void setReplyDate(Date replyDate) {
        this.replyDate = replyDate;
    }

    public String getReplyOpinion() {
        return replyOpinion;
    }

    public void setReplyOpinion(String replyOpinion) {
        this.replyOpinion = replyOpinion;
    }

    public String getReplyAttachment() {
        return replyAttachment;
    }

    public void setReplyAttachment(String replyAttachment) {
        this.replyAttachment = replyAttachment;
    }

    public String getOnlineAttachment() {
        return onlineAttachment;
    }

    public void setOnlineAttachment(String onlineAttachment) {
        this.onlineAttachment = onlineAttachment;
    }

    public String getFileAttachment() {
        return fileAttachment;
    }

    public void setFileAttachment(String fileAttachment) {
        this.fileAttachment = fileAttachment;
    }

    public String getOtherAttachment() {
        return otherAttachment;
    }

    public void setOtherAttachment(String otherAttachment) {
        this.otherAttachment = otherAttachment;
    }

    @ReferSerialTransfer(referCode = "idm-dept")
    public Long getCreateDeptId() {
        return createDeptId;
    }

    @ReferDeserialTransfer
    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }

    @ReferDeserialTransfer
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "dc_filedistribute_center_ref")
    public Long getCenterId() {
        return centerId;
    }
    @ReferDeserialTransfer
    public void setCenterId(Long centerId) {
        this.centerId = centerId;
    }

    public String getFileStsCn() {
        return fileStsCn;
    }

    public void setFileStsCn(String fileStsCn) {
        this.fileStsCn = fileStsCn;
    }

    @ReferSerialTransfer(referCode = "data-dictionary-category")
    public Long getMainActivities() {
        return mainActivities;
    }

    @ReferDeserialTransfer
    public void setMainActivities(Long mainActivities) {
        this.mainActivities = mainActivities;
    }

    @ReferSerialTransfer(referCode = "data-dictionary-category")
    public Long getSubentryActivities() {
        return subentryActivities;
    }

    @ReferDeserialTransfer
    public void setSubentryActivities(Long subentryActivities) {
        this.subentryActivities = subentryActivities;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getPrincipalItem() {
        return principalItem;
    }

    @ReferDeserialTransfer
    public void setPrincipalItem(Long principalItem) {
        this.principalItem = principalItem;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getCmitTypeCode() {
        return cmitTypeCode;
    }

    @ReferDeserialTransfer
    public void setCmitTypeCode(Long cmitTypeCode) {
        this.cmitTypeCode = cmitTypeCode;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getReceiverCmitCode() {
        return receiverCmitCode;
    }

    @ReferDeserialTransfer
    public void setReceiverCmitCode(Long receiverCmitCode) {
        this.receiverCmitCode = receiverCmitCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
}

==> ejc-ztpcdc-impl-3.0.0-20230802.031119-153-sources.jar: com/ejianc/business/dc/vo/DcSendFileVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 发文管理
 *
 * @author generator
 */
public class DcSendFileVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Integer billState; // 单据状态
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private String fileCode; // 外部编码
    private String fileInternalCode; // 内部编码
    private String fileName; // 文件名称
    private String fileVsn; // 版本
    private String fileSts; // 文件状态
    private String fileStsCn; // 文件状态中文
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date sendDate; // 发文日期
    private Long attribute; // 文件属性
    private Long filetype; // 文件类型
    private Long submitType; // 外报类型
    private String submitOrgCode; // 主送单位/部门编号
    private String submitOrgName; // 主送单位/部门
    private String submitOrgId;
    private String copyOrgId;
    private String copyOrgCode; // 抄送单位/部门编号
    private String copyOrgName; // 抄送单位/部门
    private String receiveFileCode; // 回复收文编号
    private Long centerId;//回复收文编号在分发中心表的主键id
    private Boolean needReplyFlag; // 是否需回复
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date needReplyDate; // 需回复日期
    private Boolean secretFlag; // 是否保密
    private Long bidsection; // 标段--字典pub_bidsection_code
    private Long mgrp; // 机组--字典pub_mgrp_code
    private Long specialty; // 专业--字典pub_specialty_code
    private Long sys; // 系统--字典pub_system_code
    private Long subItem; // 子项--字典pub_sub_item
    private Long materialType; // 材料类型--字典pub_material_type
    private String unitProjCode; // 单位工程代码
    private String unitProjName; // 单位工程名称
    private Long contractId; // 合同ID
    private String contractCode; // 合同编号
    private String contractName; // 合同名称
    private Boolean costFlag; // 是否涉费--字典flag_yn
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date replyDate; // 回复日期
    private String replyOpinion; // 回复意见
    private String replyAttachment; // 回复附件
    private String onlineAttachment; // 在线编辑正文附件
    private String fileAttachment; // 在线编辑自动生成的文件附件
    private String otherAttachment; // 其他附件
    private Long createDeptId; // 创建部门id
    private Long orgId; // 所属组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private Long mainActivities; // 主要活动--数据字典mainActivities
    private Long subentryActivities; // 分项活动
    private Long principalItem; // 主要种类
    private Long cmitTypeCode; // 通讯类型代码
    private Long receiverCmitCode; // 收文方通讯代码
    private String billCode; // 单据编码
    private String deptDirector; // 部门主任

    public String getFileCode() {
        return fileCode;
    }

    public void setFileCode(String fileCode) {
        this.fileCode = fileCode;
    }

    public String getFileInternalCode() {
        return fileInternalCode;
    }

    public void setFileInternalCode(String fileInternalCode) {
        this.fileInternalCode = fileInternalCode;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getFileVsn() {
        return fileVsn;
    }

    public void setFileVsn(String fileVsn) {
        this.fileVsn = fileVsn;
    }

    public String getFileSts() {
        return fileSts;
    }

    public void setFileSts(String fileSts) {
        this.fileSts = fileSts;
    }

    public Date getSendDate() {
        return sendDate;
    }

    public void setSendDate(Date sendDate) {
        this.sendDate = sendDate;
    }

    @ReferSerialTransfer(referCode = "contractCategory")
    public Long getAttribute() {
        return attribute;
    }

    @ReferDeserialTransfer
    public void setAttribute(Long attribute) {
        this.attribute = attribute;
    }

    @ReferSerialTransfer(referCode = "contractCategory")
    public Long getFiletype() {
        return filetype;
    }

    @ReferDeserialTransfer
    public void setFiletype(Long filetype) {
        this.filetype = filetype;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSubmitType() {
        return submitType;
    }

    @ReferDeserialTransfer
    public void setSubmitType(Long submitType) {
        this.submitType = submitType;
    }

    public String getSubmitOrgId() {
        return submitOrgId;
    }

    @ReferDeserialTransfer
    public void setSubmitOrgId(String submitOrgId) {
        this.submitOrgId = submitOrgId;
    }

    public String getCopyOrgId() {
        return copyOrgId;
    }

    @ReferDeserialTransfer
    public void setCopyOrgId(String copyOrgId) {
        this.copyOrgId = copyOrgId;
    }

    public String getSubmitOrgCode() {
        return submitOrgCode;
    }

    public void setSubmitOrgCode(String submitOrgCode) {
        this.submitOrgCode = submitOrgCode;
    }

    public String getSubmitOrgName() {
        return submitOrgName;
    }

    public void setSubmitOrgName(String submitOrgName) {
        this.submitOrgName = submitOrgName;
    }

    public String getCopyOrgCode() {
        return copyOrgCode;
    }

    public void setCopyOrgCode(String copyOrgCode) {
        this.copyOrgCode = copyOrgCode;
    }

    public String getCopyOrgName() {
        return copyOrgName;
    }

    public void setCopyOrgName(String copyOrgName) {
        this.copyOrgName = copyOrgName;
    }

    public String getReceiveFileCode() {
        return receiveFileCode;
    }

    public void setReceiveFileCode(String receiveFileCode) {
        this.receiveFileCode = receiveFileCode;
    }



    public Date getNeedReplyDate() {
        return needReplyDate;
    }

    public void setNeedReplyDate(Date needReplyDate) {
        this.needReplyDate = needReplyDate;
    }


    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getBidsection() {
        return bidsection;
    }

    @ReferDeserialTransfer
    public void setBidsection(Long bidsection) {
        this.bidsection = bidsection;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getMgrp() {
        return mgrp;
    }

    @ReferDeserialTransfer
    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getSpecialty() {
        return specialty;
    }

    @ReferDeserialTransfer
    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getSys() {
        return sys;
    }

    @ReferDeserialTransfer
    public void setSys(Long sys) {
        this.sys = sys;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSubItem() {
        return subItem;
    }

    @ReferDeserialTransfer
    public void setSubItem(Long subItem) {
        this.subItem = subItem;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMaterialType() {
        return materialType;
    }

    @ReferDeserialTransfer
    public void setMaterialType(Long materialType) {
        this.materialType = materialType;
    }

    public String getUnitProjCode() {
        return unitProjCode;
    }

    public void setUnitProjCode(String unitProjCode) {
        this.unitProjCode = unitProjCode;
    }

    public String getUnitProjName() {
        return unitProjName;
    }

    public void setUnitProjName(String unitProjName) {
        this.unitProjName = unitProjName;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Boolean getNeedReplyFlag() {
        return needReplyFlag;
    }

    public void setNeedReplyFlag(Boolean needReplyFlag) {
        this.needReplyFlag = needReplyFlag;
    }

    public Boolean getSecretFlag() {
        return secretFlag;
    }

    public void setSecretFlag(Boolean secretFlag) {
        this.secretFlag = secretFlag;
    }

    public Boolean getCostFlag() {
        return costFlag;
    }

    public void setCostFlag(Boolean costFlag) {
        this.costFlag = costFlag;
    }

    public Date getReplyDate() {
        return replyDate;
    }

    public void setReplyDate(Date replyDate) {
        this.replyDate = replyDate;
    }

    public String getReplyOpinion() {
        return replyOpinion;
    }

    public void setReplyOpinion(String replyOpinion) {
        this.replyOpinion = replyOpinion;
    }

    public String getReplyAttachment() {
        return replyAttachment;
    }

    public void setReplyAttachment(String replyAttachment) {
        this.replyAttachment = replyAttachment;
    }

    public String getOnlineAttachment() {
        return onlineAttachment;
    }

    public void setOnlineAttachment(String onlineAttachment) {
        this.onlineAttachment = onlineAttachment;
    }

    public String getFileAttachment() {
        return fileAttachment;
    }

    public void setFileAttachment(String fileAttachment) {
        this.fileAttachment = fileAttachment;
    }

    public String getOtherAttachment() {
        return otherAttachment;
    }

    public void setOtherAttachment(String otherAttachment) {
        this.otherAttachment = otherAttachment;
    }

    @ReferSerialTransfer(referCode = "idm-dept")
    public Long getCreateDeptId() {
        return createDeptId;
    }

    @ReferDeserialTransfer
    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }

    @ReferDeserialTransfer
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "dc_filedistribute_center_ref")
    public Long getCenterId() {
        return centerId;
    }
    @ReferDeserialTransfer
    public void setCenterId(Long centerId) {
        this.centerId = centerId;
    }

    public String getFileStsCn() {
        return fileStsCn;
    }

    public void setFileStsCn(String fileStsCn) {
        this.fileStsCn = fileStsCn;
    }

    @ReferSerialTransfer(referCode = "data-dictionary-category")
    public Long getMainActivities() {
        return mainActivities;
    }

    @ReferDeserialTransfer
    public void setMainActivities(Long mainActivities) {
        this.mainActivities = mainActivities;
    }

    @ReferSerialTransfer(referCode = "data-dictionary-category")
    public Long getSubentryActivities() {
        return subentryActivities;
    }

    @ReferDeserialTransfer
    public void setSubentryActivities(Long subentryActivities) {
        this.subentryActivities = subentryActivities;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getPrincipalItem() {
        return principalItem;
    }

    @ReferDeserialTransfer
    public void setPrincipalItem(Long principalItem) {
        this.principalItem = principalItem;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getCmitTypeCode() {
        return cmitTypeCode;
    }

    @ReferDeserialTransfer
    public void setCmitTypeCode(Long cmitTypeCode) {
        this.cmitTypeCode = cmitTypeCode;
    }

    @ReferSerialTransfer(referCode = "data-dictionary")
    public Long getReceiverCmitCode() {
        return receiverCmitCode;
    }

    @ReferDeserialTransfer
    public void setReceiverCmitCode(Long receiverCmitCode) {
        this.receiverCmitCode = receiverCmitCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public String getDeptDirector() {
        return deptDirector;
    }
    @ReferDeserialTransfer
    public void setDeptDirector(String deptDirector) {
        this.deptDirector = deptDirector;
    }
}
